% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cellLevelMetrics.R
\name{minBoundaryDistances}
\alias{minBoundaryDistances}
\title{Compute minimum boundary distances for each cell within its corresponding image structures}
\usage{
minBoundaryDistances(spe, imageCol, structColumn, allStructs, nCores = 1)
}
\arguments{
\item{spe}{SpatialExperiment object}

\item{imageCol}{character; name of the \code{colData} column specifying the image name}

\item{structColumn}{character; name of the \code{colData} column specifying structure assignments}

\item{allStructs}{sf object; contains spatial structures with corresponding image names}

\item{nCores}{integer; The number of cores to use for parallel processing (default is 1).}
}
\value{
A numeric vector containing the minimum distances between cells and structure boundaries,
values within structures have negative values.
}
\description{
Compute minimum boundary distances for each cell within its corresponding image structures
}
\examples{
library("SpatialExperiment")
data("sostaSPE")
allStructs <- reconstructShapeDensitySPE(sostaSPE,
    marks = "cellType", imageCol = "imageName",
    markSelect = "A", bndw = 3.5, thres = 0.045
)
colData(sostaSPE)$structAssign <- assingCellsToStructures(
    spe = sostaSPE, allStructs = allStructs, imageCol = "imageName"
)
colData(sostaSPE)$minDist <- minBoundaryDistances(
    spe = sostaSPE, imageCol = "imageName", structColumn = "structAssign",
    allStructs = allStructs
)
if (require("ggplot2")) {
    cbind(colData(sostaSPE), spatialCoords(sostaSPE)) |>
        as.data.frame() |>
        ggplot(aes(x = x, y = y, color = minDist)) +
        geom_point(size = 0.25) +
        scale_colour_gradient2() +
        geom_sf(data = allStructs, fill = NA, inherit.aes = FALSE) +
        facet_wrap(~imageName)
}
}
